==> mastapy-14.0.0rc3-py3-none-any.whl: mastapy/_private/_internal/implicit/enum_with_selected_value/rolling_bearing_arrangement.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private.bearings import _1945
from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import List, Type, Any, TypeVar

    Self = TypeVar("Self", bound="EnumWithSelectedValue_RollingBearingArrangement")


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_RollingBearingArrangement",)


class EnumWithSelectedValue_RollingBearingArrangement(
    mixins.EnumWithSelectedValueMixin, Enum
):
    """EnumWithSelectedValue_RollingBearingArrangement

    A specific implementation of 'EnumWithSelectedValue' for 'RollingBearingArrangement' types.
    """

    __qualname__ = "RollingBearingArrangement"

    @classmethod
    def wrapper_type(
        cls: "Type[EnumWithSelectedValue_RollingBearingArrangement]",
    ) -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_RollingBearingArrangement]",
    ) -> "_1945.RollingBearingArrangement":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _1945.RollingBearingArrangement
        """
        return _1945.RollingBearingArrangement

    @classmethod
    def implicit_type(
        cls: "Type[EnumWithSelectedValue_RollingBearingArrangement]",
    ) -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _1945.RollingBearingArrangement.type_()

    @property
    def selected_value(self: "Self") -> "_1945.RollingBearingArrangement":
        """mastapy.bearings.RollingBearingArrangement

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(self: "Self") -> "List[_1945.RollingBearingArrangement]":
        """List[mastapy.bearings.RollingBearingArrangement]

        Note:
            This property is readonly.
        """
        return None

==> mastapy-14.0.1b1-py3-none-any.whl: mastapy/_private/_internal/implicit/enum_with_selected_value/rolling_bearing_arrangement.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.bearings import _1945

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar("Self", bound="EnumWithSelectedValue_RollingBearingArrangement")


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_RollingBearingArrangement",)


class EnumWithSelectedValue_RollingBearingArrangement(
    mixins.EnumWithSelectedValueMixin, Enum
):
    """EnumWithSelectedValue_RollingBearingArrangement

    A specific implementation of 'EnumWithSelectedValue' for 'RollingBearingArrangement' types.
    """

    __qualname__ = "RollingBearingArrangement"

    @classmethod
    def wrapper_type(
        cls: "Type[EnumWithSelectedValue_RollingBearingArrangement]",
    ) -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_RollingBearingArrangement]",
    ) -> "_1945.RollingBearingArrangement":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _1945.RollingBearingArrangement
        """
        return _1945.RollingBearingArrangement

    @classmethod
    def implicit_type(
        cls: "Type[EnumWithSelectedValue_RollingBearingArrangement]",
    ) -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _1945.RollingBearingArrangement.type_()

    @property
    def selected_value(self: "Self") -> "_1945.RollingBearingArrangement":
        """mastapy.bearings.RollingBearingArrangement

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(self: "Self") -> "List[_1945.RollingBearingArrangement]":
        """List[mastapy.bearings.RollingBearingArrangement]

        Note:
            This property is readonly.
        """
        return None
